@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2016-10-30'; # DATE
-our $VERSION = '0.57'; # VERSION
+our $DATE = '2016-12-10'; # DATE
+our $VERSION = '0.58'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,6 +28,25 @@ our $COMPLETE_UTIL_TRACE = $ENV{COMPLETE_UTIL_TRACE} // 0;
 $SPEC{':package'} = {
     v => 1.1,
     summary => 'General completion routine',
+    description => <<'_',
+
+This package provides some generic completion routine that follows the
+<pm:Complete> convention (if you are looking for bash/shell tab completion
+routine, take a look at the See Also section). The main routine is
+`complete_array_elem` which tries to complete a word using choices from elements
+of supplied array. For example:
+
+    complete_array_elem(word => "a", array => ["apple", "apricot", "banana"]);
+
+The routine will first try a simple substring prefix matching. If that fails,
+will try some other methods like word-mode, character-mode, or fuzzy matching.
+These methods can be disabled using settings.
+
+There are other utility routines e.g. for converting completion answer structure
+from hash to array/array to hash, combine or modify answer, etc. These routines
+are usually used by the other more specific or higher-level completion modules.
+
+_
 };
 
 $SPEC{hashify_answer} = {
@@ -460,7 +479,7 @@ See also the `remaining` option for a more general mechanism of offering fewer
 elements.
 
 _
-        schema => ['str*', is=>1],
+        schema => ['bool*', is=>1],
     },
     remaining => {
         schema => ['code*'],
@@ -720,10 +739,27 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.57 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-30.
+This document describes version 0.58 of Complete::Util (from Perl distribution Complete-Util), released on 2016-12-10.
 
 =head1 DESCRIPTION
 
+
+This package provides some generic completion routine that follows the
+L<Complete> convention (if you are looking for bash/shell tab completion
+routine, take a look at the See Also section). The main routine is
+C<complete_array_elem> which tries to complete a word using choices from elements
+of supplied array. For example:
+
+ complete_array_elem(word => "a", array => ["apple", "apricot", "banana"]);
+
+The routine will first try a simple substring prefix matching. If that fails,
+will try some other methods like word-mode, character-mode, or fuzzy matching.
+These methods can be disabled using settings.
+
+There are other utility routines e.g. for converting completion answer structure
+from hash to array/array to hash, combine or modify answer, etc. These routines
+are usually used by the other more specific or higher-level completion modules.
+
 =head1 FUNCTIONS
 
 
@@ -884,7 +920,7 @@ completed unambiguously into C<unmount>.
 
 =item * B<sep> => I<str> (default: ",")
 
-=item * B<uniq> => I<str>
+=item * B<uniq> => I<bool>
 
 Whether list should contain unique elements.
 
@@ -1035,7 +1071,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Complete-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
 
 =head1 BUGS
 
